# x_add_INs_to_dict.R
# Kendall et al. Performance in Coding Sociolinguistic Variables (Frontiers)
#
# Edits a pronunciation dictionary (e.g. CMUdict) to add -in variants for (ING) words

# Set the path to your English dict, e.g.
path.to.dict <- "~/Documents/Aligner/Dictionary/my_eng_dict.txt"
new.dict.name<- gsub("\\.txt$", "_varing.txt", path.to.dict, perl=T)

# Read in the dictionary
dict <- scan(file=path.to.dict, what=character(), sep="\n")

# Can inspect
head(dict)

# Find entries that look like (ING) words
ing.lines <- grep("^.*\\w+[AEIOUY].*?ING ", dict, perl=T)

# Create a new entry for each one, with N as an option for final segment in place of NG
new.entries <- sapply(dict[ing.lines], function(x) gsub("NG$", "N", x, perl=T), USE.NAMES=F)

# Add these new entries
new.dict <- c(dict, new.entries)
new.dict <- sort(new.dict)

# Save the new dictionary
write(new.dict, file=new.dict.name, sep="\n")